@@ -97,7 +97,7 @@ class BaseHandler(RequestHandler):
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
             self.end_time = int(round(time.time() * 1000))
-            self.set_header("ApiTime", str(self.end_time - self.start_time))
+            self.set_header("ApiTime", f"{self.end_time - self.start_time}ms")
             if not self.original:
                 self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
@@ -186,7 +186,7 @@ class BaseHandler(RequestHandler):
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
             self.end_time = int(round(time.time() * 1000))
-            self.set_header("ApiTime", str(self.end_time - self.start_time))
+            self.set_header("ApiTime", f"{self.end_time - self.start_time}ms")
             if not self.original:
                 self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
